#include <Wire.h>
// Instructables Internet of Things Class sample code
// Circuit Displays Internet Data
// Weather data is collected in a feed
// Multiple NeoPixels visualize the weather condition
//
// Modified by Becky Stern 2017
// based on the Adafruit IO Subscription Example

// Adafruit invests time and resources providing this open source code.
// Please support Adafruit and open source hardware by purchasing
// products from Adafruit!
//
// Written by Todd Treece for Adafruit Industries
// Copyright (c) 2016 Adafruit Industries
// Licensed under the MIT license.
//
// All text above must be included in any redistribution.

/************************ Adafruit IO Configuration *******************************/

// visit io.adafruit.com if you need to create an account,
// or if you need your Adafruit IO key.
#define IO_USERNAME    "J01n"
#define IO_KEY         "aio_meXD9948esYTuxOkdMZR89du4SHk"

/******************************* WIFI Configuration **************************************/

#define WIFI_SSID       "CMPND / 9 Homestead"
#define WIFI_PASS       "9homestead"

#include "AdafruitIO_WiFi.h"
AdafruitIO_WiFi io(IO_USERNAME, IO_KEY, WIFI_SSID, WIFI_PASS);

/************************ Main Program Starts Here *******************************/
#include <ESP8266WiFi.h>
#include <AdafruitIO.h>
#include <Adafruit_MQTT.h>
#include <ArduinoHttpClient.h>
#include <Servo.h>

#include <Adafruit_NeoPixel.h>

#define PIXELS_PIN 2   //Pin connected to the NeoPixel data input
#define NUM_LEDS   4    // Number of NeoPixels
#define BRIGHTNESS 100
#define PIXEL_TYPE NEO_GRB + NEO_KHZ800   // Type of the NeoPixels (see strandtest example).
#define servo1_PIN 12  // Define the pin for servo1
Servo servo1;  // create servo object to control servo on pin 9  // create servo object to control servo on pin 10

Adafruit_NeoPixel strip = Adafruit_NeoPixel(NUM_LEDS, PIXELS_PIN, PIXEL_TYPE + NEO_KHZ800);

AdafruitIO_Feed *precipitation = io.feed("precipitation"); // set up the 'precipitation' feed

void setup() {
servo1.attach(12);
  strip.setBrightness(BRIGHTNESS);
  strip.begin();
  strip.show(); // Initialize all pixels to 'off'

  // start the serial connection
  Serial.begin(115200);

  // connect to io.adafruit.com
  Serial.print("Connecting to Adafruit IO");
  io.connect();
  
  // set up a message handler for the 'precipitation' feed.
  // the handleMessage function (defined below)
  // will be called whenever a message is
  // received from adafruit io.
  precipitation->onMessage(handleMessage);

  // wait for a connection
  while(io.status() < AIO_CONNECTED) {
    Serial.print(".");
    delay(500);
  }

  // we are connected
  Serial.println();
  Serial.println(io.statusText());

}

void loop() {

  // io.run(); is required for all sketches.
  // it should always be present at the top of your loop
  // function. it keeps the client connected to
  // io.adafruit.com, and processes any incoming data.
  io.run();

}

// this function is called whenever a message
// is received from Adafruit IO. it was attached to
// the feed in the setup() function above.
void handleMessage(AdafruitIO_Data *data) {
  
  //lightPixels(strip.Color(0, 0, 0, 0)); // reset all pixels to off when new info is received

  String forecast = data->toString(); // store the incoming weather data in a string

  Serial.print("received <- ");
  Serial.println(forecast);
  
  //the following strings store the varous IFTTT weather report words I've discovered so far
  String rain = String("Rain");
  String clear = String("clear");
  String snow = String ("snow");
  String cloudy = String ("cloudy");
  String tshirt = String("tshirt");
  String sweater = String("sweater");
  String coat = String ("coat");
  String downjacket = String ("downjacket");
  // These if statements compare the incoming weather variable to the stored conditions, and control the NeoPixels accordingly.
  
  // if there's rain in the forecast
  if (forecast.equalsIgnoreCase(rain)){
    Serial.println("precipitation feed in the forecast today is rain");
    servo1.write(0);  // Rotate servo1 90 degrees clockwise
    delay(1000);   // Return servo2 to the initial position
  }
  // if there's snow in the forecast
  if (forecast.equalsIgnoreCase(snow)){
    Serial.println("precipitation feed in the forecast today is snow");
    servo1.write(90);  // Rotate servo1 90 degrees clockwise
    delay(1000);  // Return servo2 to the initial position
  }
  // if there's sun in the forecast
  if (forecast.equalsIgnoreCase(clear)){
    Serial.println("precipitation feed in the forecast today is clear");
    servo1.write(180);   // Return servo1 to the initial position
    delay(1000); // Rotate servo2 90 degrees clockwise
  }
  // if there're clouds in the forecast
  if (forecast.equalsIgnoreCase(cloudy)){
    Serial.println("precipitation feed in the forecast today is cloudy");
    servo1.write(270); 
    delay(1000); // Return servo2 to the initial position
   }
   if (forecast.equalsIgnoreCase(tshirt)){
    Serial.println("precipitation feed in the forecast today is tshirt");
    lightPixels(strip.Color(0, 0, 0, 0));
    strip.setPixelColor(0, strip.Color(255, 0, 0, 0));
    delay(1000);   // Return servo2 to the initial position
  }// if there's snow in the forecast
  if (forecast.equalsIgnoreCase(sweater)){
    Serial.println("precipitation feed in the forecast today is sweater");
    lightPixels(strip.Color(0, 0, 0, 0));
    strip.setPixelColor(1, strip.Color(255, 255, 255, 255)); // Rotate servo1 90 degrees clockwise
    delay(1000);  // Return servo2 to the initial position
  }
  // if there's sun in the forecast
  if (forecast.equalsIgnoreCase(downjacket)){
    Serial.println("precipitation feed in the forecast today is downjacket");
    lightPixels(strip.Color(0, 0, 0, 0));
    strip.setPixelColor(2, strip.Color(255, 255, 255, 255));  // Rotate servo1 90 degrees clockwise
    servo1.write(180);   // Return servo1 to the initial position
    delay(1000); // Rotate servo2 90 degrees clockwise
  }
  // if there're clouds in the forecast
  if (forecast.equalsIgnoreCase(coat)){
    Serial.println("precipitation feed in the forecast today is coat");
    lightPixels(strip.Color(0, 0, 0, 0));
    strip.setPixelColor(3, strip.Color(255, 255, 255, 255));  // Rotate servo1 90 degrees clockwise; 
    delay(1000); // Return servo2 to the initial position
   }
   strip.show(); // display the changes
  
}

// Function to set all the NeoPixels to the specified color.
void lightPixels(uint32_t color) {
  for (int i=0; i<NUM_LEDS; ++i) {
    strip.setPixelColor(i, color);
  }
  strip.show();
}
